@@ -4,10 +4,11 @@ import logging
 import os
 from dataclasses import dataclass, field
 from enum import Enum, unique
-from typing import List
+from typing import Dict, List, Tuple
 
 import numpy as np
 from marshmallow import Schema, fields, post_load
+from marshmallow.decorators import post_dump
 
 from .action import Action
 from .goal_metadata import GoalMetadata
@@ -58,7 +59,6 @@ class ConfigManager(object):
     CONFIG_NOISE_ENABLED = 'noise_enabled'
     CONFIG_SAVE_DEBUG_IMAGES = 'save_debug_images'
     CONFIG_SAVE_DEBUG_JSON = 'save_debug_json'
-    CONFIG_SEED = 'seed'
     CONFIG_SIZE = 'size'
     CONFIG_TEAM = 'team'
     CONFIG_VIDEO_ENABLED = 'video_enabled'
@@ -112,6 +112,13 @@ class ConfigManager(object):
                 str(self.SCREEN_WIDTH_DEFAULT)
             )
 
+    def is_file_writing_enabled(self):
+        return (
+            self.is_save_debug_images() or
+            self.is_save_debug_json() or
+            self.is_video_enabled()
+        )
+
     def get_evaluation_name(self):
         return self._config.get(
             self.CONFIG_DEFAULT_SECTION,
@@ -135,13 +142,6 @@ class ConfigManager(object):
             mode
         )
 
-    def get_seed(self):
-        return self._config.getint(
-            self.CONFIG_DEFAULT_SECTION,
-            self.CONFIG_SEED,
-            fallback=None
-        )
-
     def get_size(self):
         return self._config.getint(
             self.CONFIG_DEFAULT_SECTION,
@@ -210,6 +210,9 @@ class ConfigManager(object):
             ]
         )
 
+    def get_screen_size(self) -> Tuple[int, int]:
+        return (self.get_screen_width(), self.get_screen_height())
+
     def get_screen_width(self) -> int:
         return self.get_size()
 
@@ -265,14 +268,14 @@ class GoalSchema(Schema):
     answer = fields.Dict()  # UI property
     category = fields.Str()
     description = fields.Str()
-    domainsInfo = fields.Dict()  # UI property
+    domains_info = fields.Dict(data_key='domainsInfo')  # UI property
     habituation_total = fields.Int()
     info_list = fields.List(fields.Str())
     last_preview_phase_step = fields.Int()
     last_step = fields.Int()
     metadata = fields.Dict()
-    objectsInfo = fields.Dict()  # UI property
-    sceneInfo = fields.Dict()  # UI property
+    objects_info = fields.Dict(data_key='objectsInfo')  # UI property
+    scene_info = fields.Dict(data_key='sceneInfo')  # UI property
     skip_preview_phase = fields.Bool()
     task_list = fields.List(fields.Str())
     type_list = fields.List(fields.Str())
@@ -283,7 +286,7 @@ class GoalSchema(Schema):
 
 
 class ChangeMaterialConfigSchema(Schema):
-    stepBegin = fields.Int()
+    step_begin = fields.Int(data_key='stepBegin')
     materials = fields.List(fields.Str())
 
     @post_load
@@ -292,12 +295,12 @@ class ChangeMaterialConfigSchema(Schema):
 
 
 class ForceConfigSchema(Schema):
-    stepBegin = fields.Int()
-    stepEnd = fields.Int()
+    step_begin = fields.Int(data_key='stepBegin')
+    step_end = fields.Int(data_key='stepEnd')
     vector = fields.Nested(Vector3dSchema)
     relative = fields.Bool()
     repeat = fields.Bool()
-    stepWait = fields.Int()
+    step_wait = fields.Int(data_key='stepWait')
 
     @post_load
     def make_force_config(self, data, **kwargs):
@@ -305,11 +308,11 @@ class ForceConfigSchema(Schema):
 
 
 class MoveConfigSchema(Schema):
-    stepBegin = fields.Int()
-    stepEnd = fields.Int()
+    step_begin = fields.Int(data_key='stepBegin')
+    step_end = fields.Int(data_key='stepEnd')
     vector = fields.Nested(Vector3dSchema)
     repeat = fields.Bool()
-    stepWait = fields.Int()
+    step_wait = fields.Int(data_key='stepWait')
 
     @post_load
     def make_move_config(self, data, **kwargs):
@@ -327,11 +330,11 @@ class OpenCloseConfigSchema(Schema):
 
 class PhysicsConfigSchema(Schema):
     enable = fields.Bool()
-    angularDrag = fields.Float()
+    angular_drag = fields.Float(data_key='angularDrag')
     bounciness = fields.Float()
     drag = fields.Float()
-    dynamicFriction = fields.Float()
-    staticFriction = fields.Float()
+    dynamic_friction = fields.Float(data_key='dynamicFriction')
+    static_friction = fields.Float(data_key='staticFriction')
 
     @post_load
     def make_physics_config(self, data, **kwargs):
@@ -357,11 +360,12 @@ class FloorTexturesConfigSchema(Schema):
 
 
 class ShowConfigSchema(Schema):
-    stepBegin = fields.Int()
+    step_begin = fields.Int(data_key='stepBegin')
     position = fields.Nested(Vector3dSchema)
     rotation = fields.Nested(Vector3dSchema)
     scale = fields.Nested(Vector3dSchema)
-    boundingBox = fields.List(fields.Dict())  # debug property
+    bounding_box = fields.List(fields.Dict(),
+                               data_key='boundingBox')  # debug property
 
     @post_load
     def make_show_config(self, data, **kwargs):
@@ -369,11 +373,11 @@ class ShowConfigSchema(Schema):
 
 
 class SizeConfigSchema(Schema):
-    stepBegin = fields.Int()
-    stepEnd = fields.Int()
+    step_begin = fields.Int(data_key='stepBegin')
+    step_end = fields.Int(data_key='stepEnd')
     size = fields.Nested(Vector3dSchema)
     repeat = fields.Bool()
-    stepWait = fields.Int()
+    step_wait = fields.Int(data_key='stepWait')
 
     @post_load
     def make_size_config(self, data, **kwargs):
@@ -381,7 +385,7 @@ class SizeConfigSchema(Schema):
 
 
 class SingleStepConfigSchema(Schema):
-    stepBegin = fields.Int()
+    step_begin = fields.Int(data_key='stepBegin')
 
     @post_load
     def make_single_step_config(self, data, **kwargs):
@@ -389,10 +393,10 @@ class SingleStepConfigSchema(Schema):
 
 
 class StepBeginEndConfigSchema(Schema):
-    stepBegin = fields.Int()
-    stepEnd = fields.Int()
+    step_begin = fields.Int(data_key='stepBegin')
+    step_end = fields.Int(data_key='stepEnd')
     repeat = fields.Bool()
-    stepWait = fields.Int()
+    step_wait = fields.Int(data_key='stepWait')
 
     @post_load
     def make_step_begin_end_config(self, data, **kwargs):
@@ -400,7 +404,7 @@ class StepBeginEndConfigSchema(Schema):
 
 
 class TeleportConfigSchema(Schema):
-    stepBegin = fields.Int()
+    step_begin = fields.Int(data_key='stepBegin')
     position = fields.Nested(Vector3dSchema)
 
     @post_load
@@ -421,46 +425,55 @@ class TransformConfigSchema(Schema):
 class SceneObjectSchema(Schema):
     id = fields.Str()
     type = fields.Str()  # should this be an enum?
-    centerOfMass = fields.Nested(Vector3dSchema)
-    changeMaterials = fields.List(fields.Nested(ChangeMaterialConfigSchema))
+    center_of_mass = fields.Nested(Vector3dSchema, data_key='centerOfMass')
+    change_materials = fields.List(
+        fields.Nested(ChangeMaterialConfigSchema),
+        data_key='changeMaterials')
     debug = fields.Dict()
     forces = fields.List(fields.Nested(ForceConfigSchema))
     ghosts = fields.List(fields.Nested(StepBeginEndConfigSchema))
     hides = fields.List(fields.Nested(SingleStepConfigSchema))
     kinematic = fields.Bool()
-    locationParent = fields.Str()
+    location_parent = fields.Str(data_key='locationParent')
     mass = fields.Float()
     materials = fields.List(fields.Str())
-    materialFile = fields.Str()  # deprecated; please use materials
+    # deprecated; please use materials
+    material_file = fields.Str(data_key='materialFile')
     moveable = fields.Bool()
     moves = fields.List(fields.Nested(MoveConfigSchema))
-    nullParent = fields.Nested(TransformConfigSchema)
+    null_parent = fields.Nested(TransformConfigSchema, data_key='nullParent')
     openable = fields.Bool()
     opened = fields.Bool()
-    openClose = fields.List(fields.Nested(OpenCloseConfigSchema))
+    open_close = fields.List(
+        fields.Nested(OpenCloseConfigSchema),
+        data_key='openClose')
     physics = fields.Bool()
-    physicsProperties = fields.Nested(PhysicsConfigSchema)
+    physics_properties = fields.Nested(
+        PhysicsConfigSchema,
+        data_key='physicsProperties')
     pickupable = fields.Bool()
     receptacle = fields.Bool()
-    resetCenterOfMass = fields.Bool()
+    reset_center_of_mass = fields.Bool(data_key='resetCenterOfMass')
     resizes = fields.List(fields.Nested(SizeConfigSchema))
     rotates = fields.List(fields.Nested(MoveConfigSchema))
-    salientMaterials = fields.List(fields.Str())
+    salient_materials = fields.List(fields.Str(), data_key='salientMaterials')
     seesaw = fields.Bool()
     shows = fields.List(fields.Nested(ShowConfigSchema))
     shrouds = fields.List(fields.Nested(StepBeginEndConfigSchema))
     states = fields.List(fields.List(fields.Str(), allow_none=True))
     structure = fields.Bool()
     teleports = fields.List(fields.Nested(TeleportConfigSchema))
-    togglePhysics = fields.List(fields.Nested(SingleStepConfigSchema))
+    toggle_physics = fields.List(
+        fields.Nested(SingleStepConfigSchema),
+        data_key='togglePhysics')
     torques = fields.List(fields.Nested(MoveConfigSchema))
 
     # These are deprecated, but needed for Eval 3 backwards compatibility
-    canContainTarget = fields.Bool()
+    can_contain_target = fields.Bool(data_key='canContainTarget')
     obstacle = fields.Bool()
     occluder = fields.Bool()
-    positionY = fields.Float()
-    stackTarget = fields.Bool()
+    position_y = fields.Float(data_key='positionY')
+    stack_target = fields.Bool(data_key='stackTarget')
 
     @post_load
     def make_scene_object(self, data, **kwargs):
@@ -469,39 +482,63 @@ class SceneObjectSchema(Schema):
 
 class SceneConfigurationSchema(Schema):
     # The passive agent scenes can have a None ceilingMaterial
-    ceilingMaterial = fields.Str(allow_none=True)
+    ceiling_material = fields.Str(allow_none=True, data_key='ceilingMaterial')
     debug = fields.Dict()
-    floorMaterial = fields.Str()
-    floorProperties = fields.Nested(PhysicsConfigSchema)
+    floor_material = fields.Str(data_key='floorMaterial')
+    floor_properties = fields.Nested(
+        PhysicsConfigSchema,
+        data_key='floorProperties')
     goal = fields.Nested(GoalSchema)
-    intuitivePhysics = fields.Bool()
+    intuitive_physics = fields.Bool(data_key='intuitivePhysics')
     isometric = fields.Bool()
     name = fields.Str()
     objects = fields.List(fields.Nested(SceneObjectSchema))
     observation = fields.Bool()  # deprecated; please use intuitivePhysics
-    performerStart = fields.Nested(PerformerStartSchema)
-    roomDimensions = fields.Nested(Vector3dSchema)
-    roomMaterials = fields.Nested(RoomMaterialsSchema)
+    performer_start = fields.Nested(
+        PerformerStartSchema,
+        data_key='performerStart')
+    room_dimensions = fields.Nested(Vector3dSchema, data_key='roomDimensions')
+    room_materials = fields.Nested(
+        RoomMaterialsSchema,
+        data_key='roomMaterials')
     screenshot = fields.Bool()  # developer use only; for the image generator
     version = fields.Integer()
-    wallMaterial = fields.Str()
-    wallProperties = fields.Nested(PhysicsConfigSchema)
+    wall_material = fields.Str(data_key='wallMaterial')
+    wall_properties = fields.Nested(
+        PhysicsConfigSchema,
+        data_key='wallProperties')
     holes = fields.List(fields.Nested(FloorHolesAndTexturesXZConfigSchema))
-    floorTextures = fields.List(fields.Nested(FloorTexturesConfigSchema))
+    floor_textures = fields.List(
+        fields.Nested(FloorTexturesConfigSchema),
+        data_key='floorTextures')
 
     # These are deprecated, but needed for Eval 3 backwards compatibility
     evaluation = fields.Str(allow_none=True)
-    evaluationOnly = fields.Bool()
-    evalName = fields.Str()
-    hypercubeNumber = fields.Int()
-    sceneNumber = fields.Int()
-    sequenceNumber = fields.Int()
+    evaluation_only = fields.Bool(data_key='evaluationOnly')
+    eval_name = fields.Str(data_key='evalName')
+    hypercube_number = fields.Int(data_key='hypercubeNumber')
+    scene_number = fields.Int(data_key='sceneNumber')
+    sequence_number = fields.Int(data_key='sequenceNumber')
     training = fields.Bool()
 
     @post_load
     def make_scene_configuration(self, data, **kwargs):
         return SceneConfiguration(**data)
 
+    @post_dump
+    def remove_none(self, d, **kwargs) -> Dict:
+        '''Remove all none's from dictionaries'''
+        for key, value in dict(d).items():
+            if isinstance(value, dict):
+                d[key] = self.remove_none(value)
+            if isinstance(value, list):
+                for index, val in enumerate(value):
+                    if isinstance(val, dict):
+                        value[index] = self.remove_none(val)
+            if value is None:
+                del d[key]
+        return d
+
 
 @dataclass
 class RoomMaterials:
@@ -523,15 +560,15 @@ class Goal:
     answer: dict = None  # UI property
     category: str = None
     description: str = None
-    domainsInfo: dict = None  # UI property
+    domains_info: dict = None  # UI property
     habituation_total: int = None
     info_list: list = None
     last_preview_phase_step: int = None
     last_step: int = None
     # TODO metadata objects
     metadata: dict = None
-    objectsInfo: dict = None  # UI property
-    sceneInfo: dict = None  # UI property
+    objects_info: dict = None  # UI property
+    scene_info: dict = None  # UI property
     skip_preview_phase: bool = False
     task_list: List[str] = None
     type_list: List[str] = None
@@ -539,27 +576,27 @@ class Goal:
 
 @dataclass
 class ChangeMaterialConfig:
-    stepBegin: int
+    step_begin: int
     materials: List[str]
 
 
 @dataclass
 class ForceConfig:
-    stepBegin: int
-    stepEnd: int
+    step_begin: int
+    step_end: int
     vector: Vector3d = Vector3d(0, 0, 0)
     relative: bool = False
     repeat: bool = False
-    stepWait: int = 0
+    step_wait: int = 0
 
 
 @dataclass
 class MoveConfig:
-    stepBegin: int
-    stepEnd: int
+    step_begin: int
+    step_end: int
     vector: Vector3d = Vector3d(0, 0, 0)
     repeat: bool = False
-    stepWait: int = 0
+    step_wait: int = 0
 
 
 @dataclass
@@ -571,11 +608,11 @@ class OpenCloseConfig:
 @dataclass
 class PhysicsConfig:
     enable: bool = False
-    angularDrag: float = None
+    angular_drag: float = None
     bounciness: float = None
     drag: float = None
-    dynamicFriction: float = None
-    staticFriction: float = None
+    dynamic_friction: float = None
+    static_friction: float = None
 
 
 @dataclass
@@ -592,38 +629,38 @@ class FloorTexturesConfig:
 
 @dataclass
 class ShowConfig:
-    stepBegin: int
+    step_begin: int
     position: Vector3d = Vector3d(0, 0, 0)
     rotation: Vector3d = Vector3d(0, 0, 0)
     scale: Vector3d = Vector3d(1, 1, 1)
-    boundingBox: List[dict] = field(default_factory=list)  # debug property
+    bounding_box: List[dict] = field(default_factory=list)  # debug property
 
 
 @dataclass
 class SizeConfig:
-    stepBegin: int
-    stepEnd: int
+    step_begin: int
+    step_end: int
     size: Vector3d = Vector3d(1, 1, 1)
     repeat: bool = False
-    stepWait: int = 0
+    step_wait: int = 0
 
 
 @dataclass
 class SingleStepConfig:
-    stepBegin: int
+    step_begin: int
 
 
 @dataclass
 class StepBeginEndConfig:
-    stepBegin: int
-    stepEnd: int
+    step_begin: int
+    step_end: int
     repeat: bool = False
-    stepWait: int = 0
+    step_wait: int = 0
 
 
 @dataclass
 class TeleportConfig:
-    stepBegin: int
+    step_begin: int
     position: Vector3d = Vector3d(0, 0, 0)
 
 
@@ -638,81 +675,81 @@ class TransformConfig:
 class SceneObject:
     id: str
     type: str  # should this be an enum?
-    centerOfMass: Vector3d = None
-    changeMaterials: List[ChangeMaterialConfig] = None
+    center_of_mass: Vector3d = None
+    change_materials: List[ChangeMaterialConfig] = None
     debug: dict = None
     forces: List[ForceConfig] = None
     ghosts: List[StepBeginEndConfig] = None
     hides: List[SingleStepConfig] = None
     kinematic: bool = None
-    locationParent: str = None
+    location_parent: str = None
     mass: float = None
     materials: List[str] = None
-    materialFile: str = None  # deprecated; please use materials
+    material_file: str = None  # deprecated; please use materials
     # Docs say moveable's default is dependant on type.  That could
     # be a problem for the concrete classes.  Needs more review later
     moveable: bool = None
     moves: List[MoveConfig] = None
-    nullParent: TransformConfig = None
+    null_parent: TransformConfig = None
     openable: bool = None
     opened: bool = None
-    openClose: List[OpenCloseConfig] = None
+    open_close: List[OpenCloseConfig] = None
     physics: bool = None
-    physicsProperties: PhysicsConfig = None
+    physics_properties: PhysicsConfig = None
     pickupable: bool = None
     receptacle: bool = None
-    resetCenterOfMass: bool = None
+    reset_center_of_mass: bool = None
     resizes: List[SizeConfig] = None
     rotates: List[MoveConfig] = None
-    salientMaterials: List[str] = None
+    salient_materials: List[str] = None
     seesaw: bool = None
     shows: List[ShowConfig] = None
     shrouds: List[StepBeginEndConfig] = None
     states: List[List[str]] = None
     structure: bool = None
     teleports: List[TeleportConfig] = None
-    togglePhysics: List[SingleStepConfig] = None
+    toggle_physics: List[SingleStepConfig] = None
     torques: List[MoveConfig] = None
 
     # These are deprecated, but needed for Eval 3 backwards compatibility
-    canContainTarget: bool = None
+    can_contain_target: bool = None
     obstacle: bool = None
     occluder: bool = None
-    positionY: float = None
-    stackTarget: bool = None
+    position_y: float = None
+    stack_target: bool = None
 
 
 @dataclass
 class SceneConfiguration:
     '''Class for keeping track of scene configuration'''
-    ceilingMaterial: str = None
+    ceiling_material: str = None
     debug: dict = None
-    floorMaterial: str = None
-    floorProperties: PhysicsConfig = None
+    floor_material: str = None
+    floor_properties: PhysicsConfig = None
     goal: Goal = None  # TODO change to concrete class
-    intuitivePhysics: bool = False
+    intuitive_physics: bool = False
     isometric: bool = False
     name: str = None
     objects: List[SceneObject] = field(default_factory=list)
     observation: bool = False  # deprecated; please use intuitivePhysics
-    performerStart: PerformerStart = None
-    roomDimensions: Vector3d = field(
+    performer_start: PerformerStart = None
+    room_dimensions: Vector3d = field(
         default=ConfigManager.DEFAULT_ROOM_DIMENSIONS)
-    roomMaterials: RoomMaterials = None
+    room_materials: RoomMaterials = None
     screenshot: bool = False  # developer use only; for the image generator
     version: int = None
-    wallMaterial: str = None
-    wallProperties: PhysicsConfig = None
+    wall_material: str = None
+    wall_properties: PhysicsConfig = None
     holes: List[FloorHolesAndTexturesXZConfig] = field(default_factory=list)
-    floorTextures: List[FloorTexturesConfig] = field(default_factory=list)
+    floor_textures: List[FloorTexturesConfig] = field(default_factory=list)
 
     # These are deprecated, but needed for Eval 3 backwards compatibility
     evaluation: str = None
-    evaluationOnly: bool = None
-    evalName: str = None
-    hypercubeNumber: int = None
-    sceneNumber: int = None
-    sequenceNumber: int = None
+    evaluation_only: bool = None
+    eval_name: str = None
+    hypercube_number: int = None
+    scene_number: int = None
+    sequence_number: int = None
     training: bool = None
 
     def retrieve_object_states(self,
