@@ -4,13 +4,13 @@ import glob
 import json
 import logging
 import os
-import random
-from typing import Dict, Union
+from typing import Dict, List, Optional, Union
 
 import ai2thor.controller
 import ai2thor.server
 import marshmallow
 import numpy as np
+import typeguard
 
 logger = logging.getLogger(__name__)
 
@@ -18,20 +18,17 @@ logger = logging.getLogger(__name__)
 # How far the player can reach.  I think this value needs to be bigger
 # than the MAX_MOVE_DISTANCE or else the player may not be able to move
 # into a position to reach some objects (it may be mathematically impossible).
-# TODO Reduce this number once the player can crouch down to reach and
-# pickup small objects on the floor.
-
 DEFAULT_MOVE = 0.1
 
 from .action import Action
-from .config_manager import (ConfigManager, MetadataTier, SceneConfiguration,
+from .config_manager import (ConfigManager, SceneConfiguration,
                              SceneConfigurationSchema)
 from .controller_events import (AfterStepPayload, BeforeStepPayload,
                                 EndScenePayload, EventType, StartScenePayload)
 from .controller_output_handler import ControllerOutputHandler
 from .goal_metadata import GoalMetadata
+from .parameter import Parameter
 from .step_metadata import StepMetadata
-from .validation import Validation
 
 
 def __reset_override(self, scene):
@@ -85,69 +82,24 @@ class Controller():
 
     Parameters
     ----------
-    unity_app_file: str
+    unity_app_file_path: str
     config: ConfigManager
     """
 
-    # AI2-THOR creates a square grid across the scene that is
-    # uses for "snap-to-grid" movement. (This value may not
-    # really matter because we set continuous to True in
-    # the step input.)
-    GRID_SIZE = 0.1
-
-    MAX_FORCE = 50.0
-
-    DEFAULT_HORIZON = 0
-    DEFAULT_ROTATION = 0
-    DEFAULT_FORCE = 0.5
-    DEFAULT_AMOUNT = 0.5
-    DEFAULT_IMG_COORD = 0
-    DEFAULT_OBJECT_MOVE_AMOUNT = 1
-
-    MAX_FORCE = 1
-    MIN_FORCE = 0
-    MAX_AMOUNT = 1
-    MIN_AMOUNT = 0
-
-    ROTATION_KEY = 'rotation'
-    HORIZON_KEY = 'horizon'
-    FORCE_KEY = 'force'
-    AMOUNT_KEY = 'amount'
-
-    OBJECT_IMAGE_COORDS_X_KEY = 'objectImageCoordsX'
-    OBJECT_IMAGE_COORDS_Y_KEY = 'objectImageCoordsY'
-    RECEPTACLE_IMAGE_COORDS_X_KEY = 'receptacleObjectImageCoordsX'
-    RECEPTACLE_IMAGE_COORDS_Y_KEY = 'receptacleObjectImageCoordsY'
-
-    # used for EndHabituation teleport
-    TELEPORT_X_POS = 'xPosition'
-    TELEPORT_Z_POS = 'zPosition'
-    TELEPORT_Y_ROT = 'yRotation'
-
-    # Hard coding actions that effect MoveMagnitude so the appropriate
-    # value is set based off of the action
-    # TODO: Move this to an enum or some place, so that you can determine
-    # special move interactions that way
-    FORCE_ACTIONS = ["ThrowObject", "PushObject", "PullObject"]
-    OBJECT_MOVE_ACTIONS = ["CloseObject", "OpenObject"]
-    MOVE_ACTIONS = ["MoveAhead", "MoveLeft", "MoveRight", "MoveBack"]
+    MAX_FORCE = 50.0  # DW: used for testing but had it twice
+    # once at 50.0 and the other at 1.0
 
+    @typeguard.typechecked
     def __init__(self, unity_app_file_path: str, config: ConfigManager):
 
-        self._subscribers = []
-
-        self._end_scene_not_registered = True
-
         self._controller = ai2thor.controller.Controller(
             quality='Medium',
             fullscreen=False,
-            # The headless flag does not work for me
-            headless=False,
+            headless=False,  # TODO confirm functionality
             local_executable_path=unity_app_file_path,
             width=config.get_screen_width(),
             height=config.get_screen_height(),
-            # Set the name of our Scene in our Unity app
-            scene='MCS',
+            scene='MCS',  # Unity scene name
             logs=True,
             # This constructor always initializes a scene, so add a scene
             # config to ensure it doesn't error
@@ -162,58 +114,11 @@ class Controller():
         self._on_init()
         self._set_config(config)
 
-    def subscribe(self, subscriber):
-        if subscriber not in self._subscribers:
-            self._subscribers.append(subscriber)
-
-    def remove_all_event_handlers(self):
-        self._subscribers = []
-
-    def _publish_event(self, event_type: EventType,
-                       payload: Union[StartScenePayload, BeforeStepPayload,
-                                      AfterStepPayload,
-                                      EndScenePayload]):
-        for subscriber in self._subscribers:
-            # TODO should we make a deep copy of the payload so subscribers
-            # cannot change source data?
-            # seems like performance vs safety
-
-            try:
-                subscriber.on_event(event_type, payload)
-            except Exception as msg:
-                logger.error(
-                    f"Error in event with type={event_type}" +
-                    f" to subscriber={type(subscriber)}",
-                    exc_info=msg)
-
-    def _create_event_payload_kwargs(self) -> dict:
-        return {"step_number": self.__step_number,
-                "config": self._config,
-                "scene_config": self._scene_config}
-
-    def _create_post_step_event_payload_kwargs(
-            self, wrapped_step, step_metadata, step_output: StepMetadata,
-            restricted_step_output: StepMetadata) -> dict:
-        args = self._create_event_payload_kwargs()
-        args['output_folder'] = self.__output_folder
-        args['timestamp'] = datetime.datetime.now().strftime("%Y%m%d-%H%M%S")
-        args['wrapped_step'] = wrapped_step
-        args['step_metadata'] = step_metadata
-        args['step_output'] = step_output
-        args['restricted_step_output'] = restricted_step_output
-        args['goal'] = self._goal
-        return args
-
-    # Pixel coordinates are expected to start at the top left, but
-    # in Unity, (0,0) is the bottom left.
-
-    def _convert_y_image_coord_for_unity(self, y_coord):
-        if(y_coord != 0):
-            return self._config.get_screen_height() - y_coord
-        else:
-            return y_coord
-
     def _on_init(self):
+        '''Set class variables after controller is initialized'''
+        self._subscribers = []
+        self._failure_handler_registered = False
+        self._end_scene_called = False
         self._goal = GoalMetadata()
         self.__habituation_trial = 1
         # Output folder used to save debug image, video, and JSON files.
@@ -221,7 +126,7 @@ class Controller():
         self._scene_config = None
         self.__step_number = 0
 
-    def _set_config(self, config):
+    def _set_config(self, config: ConfigManager):
         '''Allows config to be changed without changing the controller and
         attached Unity process.  This typically should only be called by the
         MCS package itself.
@@ -229,41 +134,245 @@ class Controller():
         For users, call machine_common_sense.change_config()
         '''
         self._config = config
-
         self._output_handler = ControllerOutputHandler(self._config)
+        self.parameter_converter = Parameter(config)
 
-        self.__noise_enabled = self._config.is_noise_enabled()
-        self.__seed = self._config.get_seed()
-
-        if self.__seed:
-            random.seed(self.__seed)
-
-    def end_scene(
-        self,
-        rating: Union[float, int, str] = None,
-        score: float = 1.0,
-        report: Dict[int, object] = None
-    ):
+    @typeguard.typechecked
+    def start_scene(self, config_data: Union[SceneConfiguration, Dict]) -> \
+            StepMetadata:
         """
-        Ends the current scene.  Calling end_scene() before calling
-        start_scene() will do nothing.
+        Starts a new scene using the given scene configuration data dict and
+        returns the scene output data object.
 
         Parameters
         ----------
-        rating : float or int or string, required
+        config_data : SceneConfiguration or dict that can be serialized to
+            SceneConfiguration
+            The MCS scene configuration data for the scene to start.
+
+        Returns
+        -------
+        StepMetadata
+            The output data object from the start of the scene (the output from
+            an "Initialize" action).
+        """
+
+        scene_config = self._convert_scene_config(config_data)
+
+        self._scene_config = scene_config
+        self.__habituation_trial = 1
+        self.__step_number = 0
+        self._goal = self._scene_config.retrieve_goal()
+        self._end_scene_called = False
+
+        skip_preview_phase = (scene_config.goal is not None and
+                              scene_config.goal.skip_preview_phase)
+
+        if (self._scene_config.name is not None and
+                self._config.is_file_writing_enabled()):
+            os.makedirs('./' + scene_config.name, exist_ok=True)
+            self.__output_folder = './' + scene_config.name + '/'
+            file_list = glob.glob(self.__output_folder + '*')
+            for file_path in file_list:
+                os.remove(file_path)
+
+        sc = SceneConfigurationSchema(
+            unknown=marshmallow.EXCLUDE).dump(
+            scene_config)
+        """
+        All this did for conversion was to wrap a hard-coded step
+        wrapped_step = self.wrap_step(
+            action='Initialize',
+            sceneConfig=sc
+        )
+        """
+        ai2thor_step = self.parameter_converter.wrap_step(
+            action='Initialize', sceneConfig=sc)
+        step_output = self._controller.step(ai2thor_step)
+
+        self._output_handler.set_scene_config(scene_config)
+        (pre_restrict_output, output) = self._output_handler.handle_output(
+            step_output, self._goal, self.__step_number,
+            self.__habituation_trial)
+
+        if not skip_preview_phase:
+            if (self._goal is not None and
+                    self._goal.last_preview_phase_step > 0):
+                image_list = output.image_list
+                depth_map_list = output.depth_map_list
+                object_mask_list = output.object_mask_list
+
+                logger.debug('STARTING PREVIEW PHASE...')
+
+                for _ in range(self._goal.last_preview_phase_step):
+                    output = self.step('Pass')
+                    image_list = image_list + output.image_list
+                    depth_map_list = depth_map_list + output.depth_map_list
+                    object_mask_list = (object_mask_list +
+                                        output.object_mask_list)
+
+                logger.debug('ENDING PREVIEW PHASE')
+
+                output.image_list = image_list
+                output.depth_map_list = depth_map_list
+                output.object_mask_list = object_mask_list
+
+            logger.debug('NO PREVIEW PHASE')
+
+            # TODO Should this be in the if block?  Now that we are using
+            # subscribers, we may want to always register
+            if(self._failure_handler_registered is False and
+                    self._config.is_history_enabled()):
+                # make sure history file is written when program exits
+                atexit.register(self.end_scene, rating=None, score=-1)
+                self._failure_handler_registered = True
+
+        payload = self._create_post_step_event_payload_kwargs(
+            ai2thor_step, step_output, pre_restrict_output, output)
+        start_scene_payload = StartScenePayload(**payload)
+        self._publish_event(
+            EventType.ON_START_SCENE, start_scene_payload)
+
+        return output
+
+    def _convert_scene_config(self, config_data) -> SceneConfiguration:
+        if isinstance(config_data, SceneConfiguration):
+            return config_data
+        schema = SceneConfigurationSchema()
+        return schema.load(config_data)
+
+    @typeguard.typechecked
+    def step(self, action: str, **kwargs) -> Optional[StepMetadata]:
+        """
+        Runs the given action within the current scene.
+
+        Parameters
+        ----------
+        action : string
+            A selected action string from the list of available actions.
+        **kwargs
+            Zero or more key-and-value parameters for the action.
+
+        Returns
+        -------
+        StepMetadata
+            The MCS output data object from after the selected action and the
+            physics simulation were run. Returns None if you have passed the
+            "last_step" of this scene.
+
+        Raises
+        ------
+            ValueError: If values are outside acceptable ranges or unable to
+                convert to a number.
+        """
+        if (self._goal.last_step is not None and
+                self._goal.last_step == self.__step_number):
+            logger.warning(
+                "You have passed the last step for this scene. "
+                "Ignoring your action. Please call controller.end_scene() "
+                "now.")
+            return None
+
+        if ',' in action:
+            action, kwargs = Action.input_to_action_and_params(action)
+
+        action_list = self._goal.retrieve_action_list_at_step(
+            self.__step_number)
+        # Only continue with this action step if the given action and
+        # parameters are in the restricted action list.
+        continue_with_step = any(
+            action == restricted_action and (
+                len(restricted_params.items()) == 0 or all(
+                    restricted_params.get(key) == value
+                    for key, value in kwargs.items()
+                )
+            )
+            for restricted_action, restricted_params in action_list
+        )
+
+        if not continue_with_step:
+            logger.warning(
+                f"The given action '{action}' with parameters "
+                f"'{kwargs}' isn't in the action_list. Ignoring your action. "
+                f"Please call controller.step() with an action in the "
+                f"action_list. Possible actions at step {self.__step_number}:"
+            )
+            for action_data in action_list:
+                logger.warning(f'    {action_data}')
+            return None
+
+        self.__step_number += 1
+
+        payload = self._create_event_payload_kwargs()
+        payload['action'] = action
+        payload['habituation_trial'] = self.__habituation_trial
+        payload['goal'] = self._goal
+        self._publish_event(
+            EventType.ON_BEFORE_STEP,
+            BeforeStepPayload(**payload))
+
+        if (action == 'EndHabituation'):
+            self.__habituation_trial += 1
+
+        if (self._goal.last_step is not None and
+                self._goal.last_step == self.__step_number):
+            logger.warning(
+                "This is your last step for this scene. All "
+                "your future actions will be skipped. Please call "
+                "controller.end_scene() now.")
+
+        """
+        params = self.validate_and_convert_params(action, **kwargs)
+        action = self.mcs_action_to_ai2thor_action(action)
+        step_action = self.wrap_step(action=action, **params)
+        """
+        ai2thor_step, params = self.parameter_converter.build_ai2thor_step(
+            action=action, **kwargs)
+        step_output = self._controller.step(ai2thor_step)
+
+        (pre_restrict_output, output) = self._output_handler.handle_output(
+            step_output, self._goal, self.__step_number,
+            self.__habituation_trial)
+
+        payload = self._create_post_step_event_payload_kwargs(
+            ai2thor_step, step_output, pre_restrict_output, output)
+        payload['ai2thor_action'] = action
+        payload['step_params'] = params
+        payload['action_kwargs'] = kwargs
+        self._publish_event(
+            EventType.ON_AFTER_STEP,
+            AfterStepPayload(**payload))
+
+        return output
+
+    @typeguard.typechecked
+    def end_scene(
+        self,
+        rating: Optional[float] = None,
+        score: Optional[float] = None,
+        report: Dict[int, object] = None
+    ) -> None:
+        """
+        Ends the current scene.  Calling end_scene() before calling
+        start_scene() will do nothing. Calling end_scene() twice with
+        the same scene will throw an exception.
+
+        Parameters
+        ----------
+        rating : float, optional
             The plausibility rating to classify a passive / VoE scene as either
             plausible or implausible. Not used for any interactive scenes. For
             passive agent scenes, this rating should be continuous, from 0.0
             (completely implausible) to 1.0 (completely plausible). For other
             passive scenes, this rating must be binary, either 0 (implausible)
-            or 1 (plausible). Please note that end-of-scene ratings are
+            or 1 (plausible). End-of-scene ratings are
             required for all passive / VoE scenes. (default None)
         score : float, optional
             The continuous plausibility score between 0.0 (completely
             implausible) and 1.0 (completely plausible). End-of-scene scores
             are required for all passive / VoE scenes except agent scenes.
             Not used for any interactive scenes or passive agent scenes.
-            (default 1.0)
+            (default None)
 
             Note: when an issue causes the program to exit prematurely or
             end_scene isn't properly called but history_enabled is true,
@@ -276,14 +385,14 @@ class Controller():
             Key is an int representing a step/frame number from output step
             metadata, starting at 1. Value or payload contains:
 
-                * rating : float or int or string, optional
+                * rating : float or int, optional
                     The plausibility rating to classify a passive / VoE scene
                     as either plausible or implausible. Not used for any
                     interactive scenes. For passive agent scenes, this rating
                     should be continuous, from 0.0 (completely implausible) to
                     1.0 (completely plausible). For other passive scenes, this
                     rating must be binary, either 0 (implausible) or 1
-                    (plausible). Please note that frame-by-frame ratings are no
+                    (plausible). Frame-by-frame ratings are no
                     longer required for any scenes (but end-of-scene ratings
                     are). (default None)
                 * score : float, optional
@@ -324,440 +433,32 @@ class Controller():
             }
 
         """
-        payloadArgs = self._create_event_payload_kwargs()
-        payloadArgs['rating'] = str(rating)
-        payloadArgs['score'] = score
-        payloadArgs['report'] = report
+        if(not self._end_scene_called):
+            payload = self._create_event_payload_kwargs()
+            payload['rating'] = rating
+            payload['score'] = score
+            payload['report'] = report
 
-        self._publish_event(
-            EventType.ON_END_SCENE,
-            EndScenePayload(
-                **payloadArgs))
+            self._publish_event(
+                EventType.ON_END_SCENE,
+                EndScenePayload(
+                    **payload))
+            self._end_scene_called = True
+        else:
+            raise RuntimeError("end_scene called twice with the same scene")
 
-        if (not self._end_scene_not_registered):
+        if (self._failure_handler_registered):
             atexit.unregister(self.end_scene)
-            self._end_scene_not_registered = True
+            self._failure_handler_registered = False
 
-    def _convert_scene_config(self, config_data) -> SceneConfiguration:
-        if isinstance(config_data, SceneConfiguration):
-            return config_data
-        schema = SceneConfigurationSchema()
-        return schema.load(config_data)
-
-    def start_scene(self, config_data):
-        """
-        Starts a new scene using the given scene configuration data dict and
-        returns the scene output data object.
-
-        Parameters
-        ----------
-        config_data : SceneConfiguration or dict that can be serialized to
-            SceneConfiguration
-            The MCS scene configuration data for the scene to start.
-
-        Returns
-        -------
-        StepMetadata
-            The output data object from the start of the scene (the output from
-            an "Initialize" action).
-        """
-
-        scene_config = self._convert_scene_config(config_data)
-
-        self._scene_config = scene_config
-        self.__habituation_trial = 1
-        self.__step_number = 0
-        self._goal = self._scene_config.retrieve_goal()
-
-        skip_preview_phase = (scene_config.goal is not None and
-                              scene_config.goal.skip_preview_phase)
-
-        if (self.isFileWritingEnabled()):
-            os.makedirs('./' + scene_config.name, exist_ok=True)
-            self.__output_folder = './' + scene_config.name + '/'
-            file_list = glob.glob(self.__output_folder + '*')
-            for file_path in file_list:
-                os.remove(file_path)
-
-        sc = SceneConfigurationSchema(
-            unknown=marshmallow.EXCLUDE).dump(
-            scene_config)
-        sc = self._remove_none(sc)
-        wrapped_step = self.wrap_step(
-            action='Initialize',
-            sceneConfig=sc
-        )
-        step_output = self._controller.step(wrapped_step)
-
-        self._output_handler.set_scene_config(scene_config)
-        (pre_restrict_output, output) = self._output_handler.handle_output(
-            step_output, self._goal, self.__step_number,
-            self.__habituation_trial)
-
-        if not skip_preview_phase:
-            if (self._goal is not None and
-                    self._goal.last_preview_phase_step > 0):
-                image_list = output.image_list
-                depth_map_list = output.depth_map_list
-                object_mask_list = output.object_mask_list
-
-                logger.debug('STARTING PREVIEW PHASE...')
-
-                for _ in range(self._goal.last_preview_phase_step):
-                    output = self.step('Pass')
-                    image_list = image_list + output.image_list
-                    depth_map_list = depth_map_list + output.depth_map_list
-                    object_mask_list = (object_mask_list +
-                                        output.object_mask_list)
-
-                logger.debug('ENDING PREVIEW PHASE')
-
-                output.image_list = image_list
-                output.depth_map_list = depth_map_list
-                output.object_mask_list = object_mask_list
-
-            logger.debug('NO PREVIEW PHASE')
-
-            # TODO Should this be in the if block?  Now that we are using
-            # subscribers, we may want to always register
-            if(self._end_scene_not_registered is True and
-                    self._config.is_history_enabled()):
-                # make sure history file is written when program exits
-                atexit.register(self.end_scene, rating="", score=-1)
-                self._end_scene_not_registered = False
-
-        payloadArgs = self._create_post_step_event_payload_kwargs(
-            wrapped_step, step_output, pre_restrict_output, output)
-        payload = StartScenePayload(**payloadArgs)
-        self._publish_event(
-            EventType.ON_START_SCENE, payload)
-
-        return output
-
-    def isFileWritingEnabled(self):
-        return self._scene_config.name is not None and (
-            self._config.is_save_debug_images() or
-            self._config.is_save_debug_json() or
-            self._config.is_video_enabled()
-        )
-
-    # TODO: may need to reevaluate validation strategy/error handling in the
-    # future
-    """
-    Need a validation/conversion step for what ai2thor will accept as input
-    to keep parameters more simple for the user (in this case, wrapping
-    rotation degrees into an object)
-    """
-
-    def validate_and_convert_params(self, action, **kwargs):
-        moveMagnitude = DEFAULT_MOVE
-        rotation = kwargs.get(self.ROTATION_KEY, self.DEFAULT_ROTATION)
-        horizon = kwargs.get(self.HORIZON_KEY, self.DEFAULT_HORIZON)
-        amount = kwargs.get(
-            self.AMOUNT_KEY,
-            self.DEFAULT_OBJECT_MOVE_AMOUNT
-            if action in self.OBJECT_MOVE_ACTIONS
-            else self.DEFAULT_AMOUNT
-        )
-        force = kwargs.get(self.FORCE_KEY, self.DEFAULT_FORCE)
-
-        objectImageCoordsX = kwargs.get(
-            self.OBJECT_IMAGE_COORDS_X_KEY, self.DEFAULT_IMG_COORD)
-        objectImageCoordsY = kwargs.get(
-            self.OBJECT_IMAGE_COORDS_Y_KEY, self.DEFAULT_IMG_COORD)
-        receptacleObjectImageCoordsX = kwargs.get(
-            self.RECEPTACLE_IMAGE_COORDS_X_KEY, self.DEFAULT_IMG_COORD)
-        receptacleObjectImageCoordsY = kwargs.get(
-            self.RECEPTACLE_IMAGE_COORDS_Y_KEY, self.DEFAULT_IMG_COORD)
-
-        if not Validation.is_number(amount, self.AMOUNT_KEY):
-            # The default for open/close is 1, the default for "Move" actions
-            # is 0.5
-            if action in self.OBJECT_MOVE_ACTIONS:
-                amount = self.DEFAULT_OBJECT_MOVE_AMOUNT
-            else:
-                amount = self.DEFAULT_AMOUNT
-
-        if not Validation.is_number(force, self.FORCE_KEY):
-            force = self.DEFAULT_FORCE
-
-        # Check object directions are numbers
-        if not Validation.is_number(
-                objectImageCoordsX,
-                self.OBJECT_IMAGE_COORDS_X_KEY):
-            objectImageCoordsX = self.DEFAULT_IMG_COORD
-
-        if not Validation.is_number(
-                objectImageCoordsY,
-                self.OBJECT_IMAGE_COORDS_Y_KEY):
-            objectImageCoordsY = self.DEFAULT_IMG_COORD
-
-        # Check receptacle directions are numbers
-        if not Validation.is_number(
-                receptacleObjectImageCoordsX,
-                self.RECEPTACLE_IMAGE_COORDS_X_KEY):
-            receptacleObjectImageCoordsX = self.DEFAULT_IMG_COORD
-
-        if not Validation.is_number(
-                receptacleObjectImageCoordsY,
-                self.RECEPTACLE_IMAGE_COORDS_Y_KEY):
-            receptacleObjectImageCoordsY = self.DEFAULT_IMG_COORD
-
-        amount = Validation.is_in_range(
-            amount,
-            self.MIN_AMOUNT,
-            self.MAX_AMOUNT,
-            self.DEFAULT_AMOUNT,
-            self.AMOUNT_KEY)
-        force = Validation.is_in_range(
-            force,
-            self.MIN_FORCE,
-            self.MAX_FORCE,
-            self.DEFAULT_FORCE,
-            self.FORCE_KEY)
-
-        # TODO Consider the current "head tilt" value while validating the
-        # input "horizon" value.
-
-        # Set the Move Magnitude to the appropriate amount based on the action
-        if action in self.FORCE_ACTIONS:
-            moveMagnitude = force * self.MAX_FORCE
-
-        if action in self.OBJECT_MOVE_ACTIONS:
-            moveMagnitude = amount
-
-        if action in self.MOVE_ACTIONS:
-            moveMagnitude = DEFAULT_MOVE
-
-        # Add in noise if noise is enable
-        if self.__noise_enabled:
-            rotation = rotation * (1 + self.generate_noise())
-            horizon = horizon * (1 + self.generate_noise())
-            moveMagnitude = moveMagnitude * (1 + self.generate_noise())
-
-        rotation_vector = {'y': rotation}
-        object_vector = {
-            'x': float(objectImageCoordsX),
-            'y': self._convert_y_image_coord_for_unity(
-                float(objectImageCoordsY)),
-        }
-
-        receptacle_vector = {
-            'x': float(receptacleObjectImageCoordsX),
-            'y': self._convert_y_image_coord_for_unity(
-                float(receptacleObjectImageCoordsY)
-            ),
-        }
-
-        teleportRotInput = kwargs.get(self.TELEPORT_Y_ROT)
-        teleportPosXInput = kwargs.get(self.TELEPORT_X_POS)
-        teleportPosZInput = kwargs.get(self.TELEPORT_Z_POS)
-
-        teleportRotation = None
-        teleportPosition = None
-
-        if teleportRotInput is not None and Validation.is_number(
-                teleportRotInput):
-            teleportRotation = {'y': kwargs.get(self.TELEPORT_Y_ROT)}
-        if (teleportPosXInput is not None and
-                Validation.is_number(teleportPosXInput) and
-                teleportPosZInput is not None and
-                Validation.is_number(teleportPosZInput)):
-            teleportPosition = {'x': teleportPosXInput, 'z': teleportPosZInput}
-        return dict(
-            objectId=kwargs.get("objectId", None),
-            receptacleObjectId=kwargs.get("receptacleObjectId", None),
-            rotation=rotation_vector,
-            horizon=horizon,
-            teleportRotation=teleportRotation,
-            teleportPosition=teleportPosition,
-            moveMagnitude=moveMagnitude,
-            objectImageCoords=object_vector,
-            receptacleObjectImageCoords=receptacle_vector
-        )
-
-    # Override
-    def step(self, action: str, **kwargs) -> StepMetadata:
-        """
-        Runs the given action within the current scene.
-
-        Parameters
-        ----------
-        action : string
-            A selected action string from the list of available actions.
-        **kwargs
-            Zero or more key-and-value parameters for the action.
-
-        Returns
-        -------
-        StepMetadata
-            The MCS output data object from after the selected action and the
-            physics simulation were run. Returns None if you have passed the
-            "last_step" of this scene.
-        """
-        if (self._goal.last_step is not None and
-                self._goal.last_step == self.__step_number):
-            logger.warning(
-                "You have passed the last step for this scene. "
-                "Ignoring your action. Please call controller.end_scene() "
-                "now.")
-            return None
-
-        if ',' in action:
-            action, kwargs = Action.input_to_action_and_params(action)
-
-        action_list = self._goal.retrieve_action_list_at_step(
-            self.__step_number)
-        # Only continue with this action step if the given action and
-        # parameters are in the restricted action list.
-
-        continue_with_step = False
-        for restricted_action, restricted_params in action_list:
-            if action == restricted_action:
-                # If this action doesn't have restricted parameters, or each
-                # input parameter is in the restricted parameters, it's OK.
-                if len(restricted_params.items()) == 0 or all([
-                    restricted_params.get(key) == value
-                    for key, value in kwargs.items()
-                ]):
-                    continue_with_step = True
-                    break
-        if not continue_with_step:
-            logger.warning(
-                f"The given action '{action}' with parameters "
-                f"'{kwargs}' isn't in the action_list. Ignoring your action. "
-                f"Please call controller.step() with an action in the "
-                f"action_list. Possible actions at step {self.__step_number}:"
-            )
-            for action_data in action_list:
-                logger.warning(f'    {action_data}')
-            return None
-
-        self.__step_number += 1
-
-        payloadArgs = self._create_event_payload_kwargs()
-        payloadArgs['action'] = action
-        payloadArgs['habituation_trial'] = self.__habituation_trial
-        payloadArgs['goal'] = self._goal
-        self._publish_event(
-            EventType.ON_BEFORE_STEP,
-            BeforeStepPayload(**payloadArgs))
-
-        params = self.validate_and_convert_params(action, **kwargs)
-
-        # Only call mcs_action_to_ai2thor_action AFTER calling
-        # validate_and_convert_params
-        action = self.mcs_action_to_ai2thor_action(action)
-
-        if (action == 'EndHabituation'):
-            self.__habituation_trial += 1
-
-        if (self._goal.last_step is not None and
-                self._goal.last_step == self.__step_number):
-            logger.warning(
-                "This is your last step for this scene. All "
-                "your future actions will be skipped. Please call "
-                "controller.end_scene() now.")
-
-        step_action = self.wrap_step(action=action, **params)
-        step_output = self._controller.step(step_action)
-
-        (pre_restrict_output, output) = self._output_handler.handle_output(
-            step_output, self._goal, self.__step_number,
-            self.__habituation_trial)
-
-        payloadArgs = self._create_post_step_event_payload_kwargs(
-            step_action, step_output, pre_restrict_output, output)
-        payloadArgs['ai2thor_action'] = action
-        payloadArgs['step_params'] = params
-        payloadArgs['action_kwargs'] = kwargs
-        self._publish_event(
-            EventType.ON_AFTER_STEP,
-            AfterStepPayload(**payloadArgs))
-
-        return output
-
-    def mcs_action_to_ai2thor_action(self, action):
-        if action == Action.CLOSE_OBJECT.value:
-            # The AI2-THOR Python library has buggy error checking
-            # specifically for the CloseObject action,
-            # so just use our own custom action here.
-            return "MCSCloseObject"
-
-        if action == Action.DROP_OBJECT.value:
-            return "DropHandObject"
-
-        if action == Action.OPEN_OBJECT.value:
-            # The AI2-THOR Python library has buggy error checking
-            # specifically for the OpenObject action,
-            # so just use our own custom action here.
-            return "MCSOpenObject"
-
-        # if action == Action.ROTATE_OBJECT_IN_HAND.value:
-        #     return "RotateHand"
-
-        return action
-
-    def retrieve_action_list_at_step(self, goal, step_number):
-        return goal.retrieve_action_list_at_step(step_number)
-
-    def retrieve_object_states(self, object_id):
-        """Return the state list at the current step for the object with the
-        given ID from the scene configuration data, if any."""
-        self._scene_config.retrieve_object_states(
-            object_id,
-            self.__step_number)
-
-    def stop_simulation(self):
+    @typeguard.typechecked
+    def stop_simulation(self) -> None:
         """Stop the 3D simulation environment. This controller won't work any
         more."""
         self._controller.stop()
 
-    def _remove_none(self, d):
-        '''Remove all none's from dictionaries'''
-        for key, value in dict(d).items():
-            if isinstance(value, dict):
-                d[key] = self._remove_none(value)
-            if isinstance(value, list):
-                for index, val in enumerate(value):
-                    if isinstance(val, dict):
-                        value[index] = self._remove_none(val)
-            if value is None:
-                del d[key]
-        return d
-
-    def wrap_step(self, **kwargs):
-        # whether or not to randomize segmentation mask colors
-        consistentColors = False
-        metadata_tier = self._config.get_metadata_tier()
-        if(metadata_tier == MetadataTier.ORACLE):
-            consistentColors = True
-
-        # Create the step data dict for the AI2-THOR step function.
-        return dict(
-            continuous=True,
-            gridSize=self.GRID_SIZE,
-            logs=True,
-            renderDepthImage=self._config.is_depth_maps_enabled(),
-            renderObjectImage=self._config.is_object_masks_enabled(),
-            snapToGrid=False,
-            consistentColors=consistentColors,
-            **kwargs
-        )
-
-    def generate_noise(self):
-        """
-        Returns a random value between -0.05 and 0.05 used to add noise to all
-        numerical action parameters noise_enabled is True.
-        Returns
-        -------
-        float
-            A value between -0.05 and 0.05 (using random.uniform).
-        """
-
-        return random.uniform(-0.5, 0.5)
-
-    def get_metadata_level(self):
+    @typeguard.typechecked
+    def get_metadata_level(self) -> str:
         """
         Returns the current metadata level set in the config. If none
         specified, returns 'default'.
@@ -768,3 +469,53 @@ class Controller():
             A string containing the current metadata level.
         """
         return self._config.get_metadata_tier().value
+
+    def retrieve_action_list_at_step(self, goal, step_number):
+        return goal.retrieve_action_list_at_step(step_number)
+
+    @typeguard.typechecked
+    def retrieve_object_states(self, object_id: str) -> List:
+        """Return the state list at the current step for the object with the
+        given ID from the scene configuration data, if any."""
+        return self._scene_config.retrieve_object_states(
+            object_id,
+            self.__step_number)
+
+    def subscribe(self, subscriber):
+        if subscriber not in self._subscribers:
+            self._subscribers.append(subscriber)
+
+    def remove_all_event_handlers(self):
+        self._subscribers = []
+
+    @typeguard.typechecked
+    def _publish_event(self, event_type: EventType,
+                       payload: Union[StartScenePayload, BeforeStepPayload,
+                                      AfterStepPayload,
+                                      EndScenePayload]):
+        for subscriber in self._subscribers:
+            try:
+                subscriber.on_event(event_type, payload)
+            except Exception as msg:
+                logger.error(
+                    f"Error in event with type={event_type}" +
+                    f" to subscriber={type(subscriber)}",
+                    exc_info=msg)
+
+    def _create_event_payload_kwargs(self) -> dict:
+        return {"step_number": self.__step_number,
+                "config": self._config,
+                "scene_config": self._scene_config}
+
+    def _create_post_step_event_payload_kwargs(
+            self, wrapped_step, step_metadata, step_output: StepMetadata,
+            restricted_step_output: StepMetadata) -> dict:
+        args = self._create_event_payload_kwargs()
+        args['output_folder'] = self.__output_folder
+        args['timestamp'] = datetime.datetime.now().strftime("%Y%m%d-%H%M%S")
+        args['wrapped_step'] = wrapped_step
+        args['step_metadata'] = step_metadata
+        args['step_output'] = step_output
+        args['restricted_step_output'] = restricted_step_output
+        args['goal'] = self._goal
+        return args
