@@ -119,8 +119,7 @@ class AbstractExecutionCache(ABC):
         '''returns a Path object for the path to the directory for the given
          version.
         '''
-        ver_path = self._base / version
-        return ver_path
+        return self._base / version
 
     def has_version(self, version: str) -> bool:
         '''Return whether the cache has the given version'''
