@@ -8,6 +8,7 @@ from machine_common_sense.config_manager import (ChangeMaterialConfig,
                                                  MoveConfig, OpenCloseConfig,
                                                  PhysicsConfig,
                                                  SceneConfiguration,
+                                                 SceneConfigurationSchema,
                                                  SceneObjectSchema, ShowConfig,
                                                  SingleStepConfig, SizeConfig,
                                                  StepBeginEndConfig,
@@ -79,13 +80,11 @@ class TestConfigManager(unittest.TestCase):
                                     'config_level2_debug.ini'))
     def test_init_no_override_with_env_var_and_dict(self):
         config_options = {
-            'metadata': 'oracle',
-            'seed': 10
+            'metadata': 'oracle'
         }
         config_mngr = ConfigManager(config_options)
         self.assertEqual(config_mngr.get_metadata_tier(),
                          MetadataTier.LEVEL_2)
-        self.assertEqual(config_mngr.get_seed(), None)
 
     @mock_env(MCS_CONFIG_FILE_PATH=('machine_common_sense/scripts/'
                                     'config_level2_debug.ini'))
@@ -94,8 +93,7 @@ class TestConfigManager(unittest.TestCase):
     def test_init_env_var_and_dict_function_calls(
             self, _read_in_config_dict, _read_in_config_file):
         config_options = {
-            'metadata': 'oracle',
-            'seed': 10
+            'metadata': 'oracle'
         }
         _ = ConfigManager(config_options)
         _read_in_config_dict.assert_not_called()
@@ -107,7 +105,6 @@ class TestConfigManager(unittest.TestCase):
         config_mngr = ConfigManager(config_file_or_dict=config_file)
         self.assertEqual(config_mngr.get_metadata_tier(),
                          MetadataTier.LEVEL_2)
-        self.assertEqual(config_mngr.get_seed(), None)
 
     def test_init_with_filepath_missing(self):
         '''Provided config file path must exist or an exception occurs'''
@@ -122,8 +119,7 @@ class TestConfigManager(unittest.TestCase):
         config_options = {
             'metadata': 'oracle',
             'video_enabled': 'false',
-            'save_debug_images': True,
-            'seed': 10
+            'save_debug_images': True
         }
 
         config_mngr = ConfigManager(config_options)
@@ -133,7 +129,6 @@ class TestConfigManager(unittest.TestCase):
                          MetadataTier.ORACLE)
         self.assertFalse(config_mngr.is_video_enabled())
         self.assertTrue(config_mngr.is_save_debug_images())
-        self.assertEqual(config_mngr.get_seed(), 10)
 
     def test_validate_screen_size(self):
         self.config_mngr._config[
@@ -187,17 +182,6 @@ class TestConfigManager(unittest.TestCase):
             self.config_mngr.get_metadata_tier().value,
             'oracle')
 
-    def test_get_seed(self):
-        self.assertEqual(self.config_mngr.get_seed(), None)
-
-        self.config_mngr._config[
-            self.config_mngr.CONFIG_DEFAULT_SECTION
-        ][
-            self.config_mngr.CONFIG_SEED
-        ] = '1'
-
-        self.assertEqual(self.config_mngr.get_seed(), 1)
-
     def test_get_size(self):
         self.assertEqual(self.config_mngr.get_size(), 600)
 
@@ -439,120 +423,120 @@ class TestSceneConfig(unittest.TestCase):
 
         assert object_1.id == 'id_1'
         assert object_1.type == 'type_1'
-        assert object_1.centerOfMass is None
-        assert object_1.changeMaterials is None
+        assert object_1.center_of_mass is None
+        assert object_1.change_materials is None
         assert object_1.debug is None
         assert object_1.forces is None
         assert object_1.ghosts is None
         assert object_1.hides is None
         assert object_1.kinematic is None
-        assert object_1.locationParent is None
+        assert object_1.location_parent is None
         assert object_1.mass is None
         assert object_1.materials is None
         assert object_1.moveable is None
         assert object_1.moves is None
-        assert object_1.nullParent is None
+        assert object_1.null_parent is None
         assert object_1.openable is None
         assert object_1.opened is None
-        assert object_1.openClose is None
+        assert object_1.open_close is None
         assert object_1.physics is None
-        assert object_1.physicsProperties is None
+        assert object_1.physics_properties is None
         assert object_1.pickupable is None
         assert object_1.receptacle is None
-        assert object_1.resetCenterOfMass is None
+        assert object_1.reset_center_of_mass is None
         assert object_1.resizes is None
         assert object_1.rotates is None
-        assert object_1.salientMaterials is None
+        assert object_1.salient_materials is None
         assert object_1.shows is None
         assert object_1.shrouds is None
         assert object_1.states is None
         assert object_1.structure is None
         assert object_1.teleports is None
-        assert object_1.togglePhysics is None
+        assert object_1.toggle_physics is None
         assert object_1.torques is None
 
         assert object_2.id == 'id_2'
         assert object_2.type == 'type_2'
-        assert object_2.centerOfMass == Vector3d(x=0.01, y=0.02, z=0.03)
-        assert object_2.changeMaterials == [ChangeMaterialConfig(
-            stepBegin=10,
+        assert object_2.center_of_mass == Vector3d(x=0.01, y=0.02, z=0.03)
+        assert object_2.change_materials == [ChangeMaterialConfig(
+            step_begin=10,
             materials=['material_3', 'material_4']
         )]
         assert object_2.debug == {'key': 'value'}
         assert object_2.forces == [ForceConfig(
             relative=True,
-            stepBegin=11,
-            stepEnd=12,
+            step_begin=11,
+            step_end=12,
             vector=Vector3d(x=0.04, y=0.05, z=0.06)
         )]
         assert object_2.ghosts == [StepBeginEndConfig(
-            stepBegin=13,
-            stepEnd=14
+            step_begin=13,
+            step_end=14
         )]
-        assert object_2.hides == [SingleStepConfig(stepBegin=15)]
+        assert object_2.hides == [SingleStepConfig(step_begin=15)]
         assert object_2.kinematic is True
-        assert object_2.locationParent == 'parent_id'
+        assert object_2.location_parent == 'parent_id'
         assert object_2.mass == 12.34
         assert object_2.materials == ['material_1', 'material_2']
         assert object_2.moveable is True
         assert object_2.moves == [MoveConfig(
-            stepBegin=16,
-            stepEnd=17,
+            step_begin=16,
+            step_end=17,
             vector=Vector3d(x=0.07, y=0.08, z=0.09)
         )]
-        assert object_2.nullParent == TransformConfig(
+        assert object_2.null_parent == TransformConfig(
             position=Vector3d(x=0.11, y=0.12, z=0.13),
             rotation=Vector3d(x=0.14, y=0.15, z=0.16),
             scale=Vector3d(x=0.17, y=0.18, z=0.19)
         )
         assert object_2.openable is True
         assert object_2.opened is True
-        assert object_2.openClose == [OpenCloseConfig(open=True, step=18)]
+        assert object_2.open_close == [OpenCloseConfig(open=True, step=18)]
         assert object_2.physics is True
-        assert object_2.physicsProperties == PhysicsConfig(
+        assert object_2.physics_properties == PhysicsConfig(
             enable=True,
-            angularDrag=1,
+            angular_drag=1,
             bounciness=2,
             drag=3,
-            dynamicFriction=4,
-            staticFriction=5
+            dynamic_friction=4,
+            static_friction=5
         )
         assert object_2.pickupable is True
         assert object_2.receptacle is True
-        assert object_2.resetCenterOfMass is True
+        assert object_2.reset_center_of_mass is True
         assert object_2.resizes == [SizeConfig(
-            stepBegin=19,
-            stepEnd=20,
+            step_begin=19,
+            step_end=20,
             size=Vector3d(x=0.21, y=0.22, z=0.23)
         )]
         assert object_2.rotates == [MoveConfig(
-            stepBegin=21,
-            stepEnd=22,
+            step_begin=21,
+            step_end=22,
             vector=Vector3d(x=0.24, y=0.25, z=0.26)
         )]
-        assert object_2.salientMaterials == ['salient_1', 'salient_2']
+        assert object_2.salient_materials == ['salient_1', 'salient_2']
         assert object_2.shows == [ShowConfig(
-            stepBegin=23,
+            step_begin=23,
             position=Vector3d(x=0.31, y=0.32, z=0.33),
             rotation=Vector3d(x=0.34, y=0.35, z=0.36),
             scale=Vector3d(x=0.37, y=0.38, z=0.39)
         )]
         assert object_2.shrouds == [StepBeginEndConfig(
-            stepBegin=24,
-            stepEnd=25
+            step_begin=24,
+            step_end=25
         )]
         assert object_2.states == [
             ['state_1'], [], ['state_2'], ['state_1', 'state_3']
         ]
         assert object_2.structure is True
         assert object_2.teleports == [TeleportConfig(
-            stepBegin=26,
+            step_begin=26,
             position=Vector3d(x=0.41, y=0.42, z=0.43)
         )]
-        assert object_2.togglePhysics == [SingleStepConfig(stepBegin=27)]
+        assert object_2.toggle_physics == [SingleStepConfig(step_begin=27)]
         assert object_2.torques == [MoveConfig(
-            stepBegin=28,
-            stepEnd=29,
+            step_begin=28,
+            step_end=29,
             vector=Vector3d(x=0.44, y=0.45, z=0.46)
         )]
 
@@ -696,5 +680,50 @@ class TestSceneConfig(unittest.TestCase):
         })
 
 
+class TestSchemeConfigurationSchema(unittest.TestCase):
+
+    def setUp(self):
+        self.scheme_config = SceneConfigurationSchema()
+
+    def test_remove_none(self):
+        actual = self.scheme_config.remove_none({})
+        self.assertEqual({}, actual)
+
+        actual = self.scheme_config.remove_none({"test": None})
+        self.assertEqual({}, actual)
+
+        actual = self.scheme_config.remove_none({"test": 1})
+        self.assertEqual({"test": 1}, actual)
+
+        actual = self.scheme_config.remove_none({"test": 1, "none": None})
+        self.assertEqual({"test": 1}, actual)
+
+        actual = self.scheme_config.remove_none({"test1": {"test2": 1}})
+        self.assertEqual({"test1": {"test2": 1}}, actual)
+
+        actual = self.scheme_config.remove_none(
+            {"test1": {"test2": 1, "none": None}})
+        self.assertEqual({"test1": {"test2": 1}}, actual)
+
+        actual = self.scheme_config.remove_none(
+            {"test1": {"test2": 1}, "none": None})
+        self.assertEqual({"test1": {"test2": 1}}, actual)
+
+        actual = self.scheme_config.remove_none(
+            {"test1": {"test2": 1, "none": None}, "none": None})
+        self.assertEqual({"test1": {"test2": 1}}, actual)
+
+        actual = self.scheme_config.remove_none({"test1": [{"test2": None}]})
+        self.assertEqual({"test1": [{}]}, actual)
+
+        actual = self.scheme_config.remove_none(
+            {"test1": [{"test2": None, "test3": "test"}]})
+        self.assertEqual({"test1": [{"test3": "test"}]}, actual)
+
+        actual = self.scheme_config.remove_none(
+            {"test1": [{"test2": None}], "test3": False})
+        self.assertEqual({"test1": [{}], "test3": False}, actual)
+
+
 if __name__ == '__main__':
     unittest.main()
